@@ -27,8 +27,8 @@
 #include <glib.h>
 
 #define GDK_MAJOR_VERSION (3)
-#define GDK_MINOR_VERSION (4)
-#define GDK_MICRO_VERSION (4)
+#define GDK_MINOR_VERSION (8)
+#define GDK_MICRO_VERSION (0)
 
 /**
  * GDK_DISABLE_DEPRECATION_WARNINGS:
@@ -80,6 +80,26 @@
  */
 #define GDK_VERSION_3_4         (G_ENCODE_VERSION (3, 4))
 
+/**
+ * GDK_VERSION_3_6:
+ *
+ * A macro that evaluates to the 3.6 version of GDK, in a format
+ * that can be used by the C pre-processor.
+ *
+ * Since: 3.6
+ */
+#define GDK_VERSION_3_6         (G_ENCODE_VERSION (3, 6))
+
+/**
+ * GDK_VERSION_3_8:
+ *
+ * A macro that evaluates to the 3.8 version of GDK, in a format
+ * that can be used by the C pre-processor.
+ *
+ * Since: 3.8
+ */
+#define GDK_VERSION_3_8         (G_ENCODE_VERSION (3, 8))
+
 
 /* evaluates to the current stable version; for development cycles,
  * this means the next stable target
@@ -105,7 +125,7 @@
  * The definition should be one of the predefined GDK version
  * macros: %GDK_VERSION_3_0, %GDK_VERSION_3_2,...
  *
- * This macro defines the lower bound for the GLib API to use.
+ * This macro defines the lower bound for the GDK API to use.
  *
  * If a function has been deprecated in a newer version of GDK,
  * it is possible to use this symbol to avoid the compiler warnings
@@ -114,7 +134,7 @@
  * Since: 3.4
  */
 #ifndef GDK_VERSION_MIN_REQUIRED
-# define GDK_VERSION_MIN_REQUIRED      (GDK_VERSION_PREV_STABLE)
+# define GDK_VERSION_MIN_REQUIRED      (GDK_VERSION_CUR_STABLE)
 #endif
 
 /**
@@ -193,4 +213,32 @@
 # define GDK_AVAILABLE_IN_3_4
 #endif
 
+#if GDK_VERSION_MIN_REQUIRED >= GDK_VERSION_3_6
+# define GDK_DEPRECATED_IN_3_6                GDK_DEPRECATED
+# define GDK_DEPRECATED_IN_3_6_FOR(f)         GDK_DEPRECATED_FOR(f)
+#else
+# define GDK_DEPRECATED_IN_3_6
+# define GDK_DEPRECATED_IN_3_6_FOR(f)
+#endif
+
+#if GDK_VERSION_MAX_ALLOWED < GDK_VERSION_3_6
+# define GDK_AVAILABLE_IN_3_6                 GDK_UNAVAILABLE(3, 6)
+#else
+# define GDK_AVAILABLE_IN_3_6
+#endif
+
+#if GDK_VERSION_MIN_REQUIRED >= GDK_VERSION_3_8
+# define GDK_DEPRECATED_IN_3_8                GDK_DEPRECATED
+# define GDK_DEPRECATED_IN_3_8_FOR(f)         GDK_DEPRECATED_FOR(f)
+#else
+# define GDK_DEPRECATED_IN_3_8
+# define GDK_DEPRECATED_IN_3_8_FOR(f)
+#endif
+
+#if GDK_VERSION_MAX_ALLOWED < GDK_VERSION_3_8
+# define GDK_AVAILABLE_IN_3_8                 GDK_UNAVAILABLE(3, 8)
+#else
+# define GDK_AVAILABLE_IN_3_8
+#endif
+
 #endif  /* __GDK_VERSION_MACROS_H__ */
